import { PostQueryHookData } from "@postgresql-typed/util";
declare const _default: import("@postgresql-typed/util").PgTExtension<PgTCacheOptions>;
export default _default;
export interface PgTCacheOptions {
    /**
     * The connection string URI.
     */
    uri?: string;
    /**
     * The namespace to use for the cache.
     *
     * @default "pgt"
     */
    namespace?: string;
    /**
     * The TTL for the cache.
     *
     * Set to `0` to disable TTL.
     *
     * @default 1000 * 60 * 15 // (15 minutes)
     */
    ttl?: number;
    /**
     * The types of queries to cache.
     *
     * @default ["select"]
     */
    types?: ("select" | "insert" | "update" | "delete")[];
}
export interface PgTCacheContext {
    /**
     * Whether the query should be cached.
     *
     * @default true
     */
    enabled?: boolean;
    /**
     * The TTL for the cache.
     *
     * Set to `0` to disable TTL.
     *
     * @default "What was set in the config file"
     */
    ttl?: number;
    /**
     * The key to use for the cache.
     *
     * If not provided, the key will be generated from the query.
     *
     * @default undefined
     */
    key?: string;
    /**
     * Do NOT set this manually.
     *
     * This is set by the extension to the cached value.
     *
     * @default undefined
     */
    cache?: PostQueryHookData["output"];
}
